from idp_authentication.enums import ChoiceEnum
from idp_authentication.users.base_classes.base_use_case import BaseUseCase


class GetAllowedRecordIdentifiersUseCase(BaseUseCase):
    """Get allowed app entity records identifiers use case."""

    def execute(
        self, user, role: ChoiceEnum, app_entity_type: str, permission: str = None
    ):
        with self.users_unit_of_work as unit_of_work:
            return self._get_allowed_app_entity_records_identifiers(
                user=user,
                role=role,
                app_entity_type=app_entity_type,
                permission=permission,
                unit_of_work=unit_of_work,
            )



from abc import ABC, abstractmethod

from idp_authentication.users.domain.ports.repository import (
    UserRepositoryPort,
    UserRoleRepositoryPort,
)
from idp_authentication.users.domain.ports.session import SessionPort


class UnitOfWorkPort(ABC):
    session: SessionPort

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        # If anything is left in the session, rollback
        self.rollback()

    @abstractmethod
    def commit(self):
        """Commit"""

    @abstractmethod
    def rollback(self):
        """Rollback"""


class UsersUnitOfWorkPort(UnitOfWorkPort, ABC):
    user_repository: UserRepositoryPort
    user_role_repository: UserRoleRepositoryPort
